@@ -9,27 +9,29 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+from calendar import timegm
 import collections
 from hashlib import sha1
 import hmac
 import json
 import os
 import time
+from urllib import parse
 
-import six
-from six.moves.urllib import parse
-
+from openstack import _log
+from openstack.cloud import _utils
+from openstack import exceptions
 from openstack.object_store.v1 import account as _account
 from openstack.object_store.v1 import container as _container
-from openstack.object_store.v1 import obj as _obj
 from openstack.object_store.v1 import info as _info
-from openstack import exceptions
-from openstack import _log
+from openstack.object_store.v1 import obj as _obj
 from openstack import proxy
-from openstack.cloud import _utils
 
 DEFAULT_OBJECT_SEGMENT_SIZE = 1073741824  # 1GB
 DEFAULT_MAX_FILE_SIZE = (5 * 1024 * 1024 * 1024 + 2) / 2
+EXPIRES_ISO8601_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
+SHORT_EXPIRES_ISO8601_FORMAT = '%Y-%m-%d'
 
 
 class Proxy(proxy.Proxy):
@@ -42,6 +44,45 @@ class Proxy(proxy.Proxy):
 
     log = _log.setup_logging('openstack')
 
+    def _extract_name(self, url, service_type=None, project_id=None):
+        url_path = parse.urlparse(url).path.strip()
+        # Remove / from the beginning to keep the list indexes of interesting
+        # things consistent
+        if url_path.startswith('/'):
+            url_path = url_path[1:]
+
+        # Split url into parts and exclude potential project_id in some urls
+        url_parts = [
+            x for x in url_path.split('/') if (
+                x != project_id
+                and (
+                    not project_id
+                    or (project_id and x != 'AUTH_' + project_id)
+                ))
+        ]
+        # Strip leading version piece so that
+        # GET /v1/AUTH_xxx
+        # returns ['AUTH_xxx']
+        if (url_parts[0]
+                and url_parts[0][0] == 'v'
+                and url_parts[0][1] and url_parts[0][1].isdigit()):
+            url_parts = url_parts[1:]
+
+        # Strip out anything that's empty or None
+        parts = [part for part in url_parts if part]
+
+        # Getting the root of an endpoint is doing version discovery
+        if not parts:
+            return ['account']
+
+        if len(parts) == 1:
+            if 'endpoints' in parts:
+                return ['endpoints']
+            else:
+                return ['container']
+        else:
+            return ['object']
+
     def get_account_metadata(self):
         """Get metadata for this account.
 
@@ -318,7 +359,10 @@ class Proxy(proxy.Proxy):
         if sha256:
             headers[self._connection._OBJECT_SHA256_KEY] = sha256 or ''
         for (k, v) in metadata.items():
-            headers['x-object-meta-' + k] = v
+            if not k.lower().startswith('x-object-meta-'):
+                headers['x-object-meta-' + k] = v
+            else:
+                headers[k] = v
 
         container_name = self._get_container_name(container=container)
         endpoint = '{container}/{name}'.format(container=container_name,
@@ -598,9 +642,6 @@ class Proxy(proxy.Proxy):
             caps = self.get_info()
         except exceptions.SDKException as e:
             if e.response.status_code in (404, 412):
-                # Clear the exception so that it doesn't linger
-                # and get reported as an Inner Exception later
-                _utils._exc_clear()
                 server_max_file_size = DEFAULT_MAX_FILE_SIZE
                 self._connection.log.info(
                     "Swift capabilities not supported. "
@@ -691,10 +732,22 @@ class Proxy(proxy.Proxy):
             account_meta = self.get_account_metadata()
             temp_url_key = (account_meta.meta_temp_url_key_2
                             or account_meta.meta_temp_url_key)
-        if temp_url_key and not isinstance(temp_url_key, six.binary_type):
+        if temp_url_key and not isinstance(temp_url_key, bytes):
             temp_url_key = temp_url_key.encode('utf8')
         return temp_url_key
 
+    def _check_temp_url_key(self, container=None, temp_url_key=None):
+        if temp_url_key:
+            if not isinstance(temp_url_key, bytes):
+                temp_url_key = temp_url_key.encode('utf8')
+        else:
+            temp_url_key = self.get_temp_url_key(container)
+        if not temp_url_key:
+            raise exceptions.SDKException(
+                'temp_url_key was not given, nor was a temporary url key'
+                ' found for the account or the container.')
+        return temp_url_key
+
     def generate_form_signature(
             self, container, object_prefix, redirect_url, max_file_size,
             max_upload_count, timeout, temp_url_key=None):
@@ -731,15 +784,9 @@ class Proxy(proxy.Proxy):
             raise exceptions.SDKException(
                 'Please use a positive <timeout> value.')
         expires = int(time.time() + int(timeout))
-        if temp_url_key:
-            if not isinstance(temp_url_key, six.binary_type):
-                temp_url_key = temp_url_key.encode('utf8')
-        else:
-            temp_url_key = self.get_temp_url_key(container)
-        if not temp_url_key:
-            raise exceptions.SDKException(
-                'temp_url_key was not given, nor was a temporary url key'
-                ' found for the account or the container.')
+
+        temp_url_key = self._check_temp_url_key(container=container,
+                                                temp_url_key=temp_url_key)
 
         res = self._get_resource(_container.Container, container)
         endpoint = parse.urlparse(self.get_endpoint())
@@ -747,8 +794,138 @@ class Proxy(proxy.Proxy):
 
         data = '%s\n%s\n%s\n%s\n%s' % (path, redirect_url, max_file_size,
                                        max_upload_count, expires)
-        if six.PY3:
-            data = data.encode('utf8')
+        data = data.encode('utf8')
         sig = hmac.new(temp_url_key, data, sha1).hexdigest()
 
         return (expires, sig)
+
+    def generate_temp_url(
+            self, path, seconds, method, absolute=False, prefix=False,
+            iso8601=False, ip_range=None, temp_url_key=None):
+        """Generates a temporary URL that gives unauthenticated access to the
+        Swift object.
+
+        :param path: The full path to the Swift object or prefix if
+            a prefix-based temporary URL should be generated. Example:
+            /v1/AUTH_account/c/o or /v1/AUTH_account/c/prefix.
+        :param seconds: time in seconds or ISO 8601 timestamp.
+            If absolute is False and this is the string representation of an
+            integer, then this specifies the amount of time in seconds for
+            which the temporary URL will be valid.
+            If absolute is True then this specifies an absolute time at which
+            the temporary URL will expire.
+        :param method: A HTTP method, typically either GET or PUT, to allow
+            for this temporary URL.
+        :param absolute: if True then the seconds parameter is interpreted as a
+            Unix timestamp, if seconds represents an integer.
+        :param prefix: if True then a prefix-based temporary URL will be
+            generated.
+        :param iso8601: if True, a URL containing an ISO 8601 UTC timestamp
+            instead of a UNIX timestamp will be created.
+        :param ip_range: if a valid ip range, restricts the temporary URL to
+            the range of ips.
+        :param temp_url_key:
+          The X-Account-Meta-Temp-URL-Key for the account. Optional, if
+          omitted, the key will be fetched from the container or the account.
+        :raises ValueError: if timestamp or path is not in valid format.
+        :return: the path portion of a temporary URL
+        """
+        try:
+            try:
+                timestamp = float(seconds)
+            except ValueError:
+                formats = (
+                    EXPIRES_ISO8601_FORMAT,
+                    EXPIRES_ISO8601_FORMAT[:-1],
+                    SHORT_EXPIRES_ISO8601_FORMAT)
+                for f in formats:
+                    try:
+                        t = time.strptime(seconds, f)
+                    except ValueError:
+                        t = None
+                    else:
+                        if f == EXPIRES_ISO8601_FORMAT:
+                            timestamp = timegm(t)
+                        else:
+                            # Use local time if UTC designator is missing.
+                            timestamp = int(time.mktime(t))
+
+                        absolute = True
+                        break
+
+                if t is None:
+                    raise ValueError()
+            else:
+                if not timestamp.is_integer():
+                    raise ValueError()
+                timestamp = int(timestamp)
+                if timestamp < 0:
+                    raise ValueError()
+        except ValueError:
+            raise ValueError('time must either be a whole number '
+                             'or in specific ISO 8601 format.')
+
+        if isinstance(path, bytes):
+            try:
+                path_for_body = path.decode('utf-8')
+            except UnicodeDecodeError:
+                raise ValueError('path must be representable as UTF-8')
+        else:
+            path_for_body = path
+
+        parts = path_for_body.split('/', 4)
+        if len(parts) != 5 or parts[0] or not all(
+                parts[1:(4 if prefix else 5)]):
+            if prefix:
+                raise ValueError('path must at least contain /v1/a/c/')
+            else:
+                raise ValueError('path must be full path to an object'
+                                 ' e.g. /v1/a/c/o')
+
+        standard_methods = ['GET', 'PUT', 'HEAD', 'POST', 'DELETE']
+        if method.upper() not in standard_methods:
+            self.log.warning('Non default HTTP method %s for tempurl '
+                             'specified, possibly an error', method.upper())
+
+        if not absolute:
+            expiration = int(time.time() + timestamp)
+        else:
+            expiration = timestamp
+
+        hmac_parts = [method.upper(), str(expiration),
+                      ('prefix:' if prefix else '') + path_for_body]
+
+        if ip_range:
+            if isinstance(ip_range, bytes):
+                try:
+                    ip_range = ip_range.decode('utf-8')
+                except UnicodeDecodeError:
+                    raise ValueError(
+                        'ip_range must be representable as UTF-8'
+                    )
+            hmac_parts.insert(0, "ip=%s" % ip_range)
+
+        hmac_body = u'\n'.join(hmac_parts)
+
+        temp_url_key = self._check_temp_url_key(temp_url_key=temp_url_key)
+
+        sig = hmac.new(temp_url_key, hmac_body.encode('utf-8'),
+                       sha1).hexdigest()
+
+        if iso8601:
+            expiration = time.strftime(
+                EXPIRES_ISO8601_FORMAT, time.gmtime(expiration))
+
+        temp_url = u'{path}?temp_url_sig={sig}&temp_url_expires={exp}'.format(
+            path=path_for_body, sig=sig, exp=expiration)
+
+        if ip_range:
+            temp_url += u'&temp_url_ip_range={}'.format(ip_range)
+
+        if prefix:
+            temp_url += u'&temp_url_prefix={}'.format(parts[4])
+        # Have return type match path from caller
+        if isinstance(path, bytes):
+            return temp_url.encode('utf-8')
+        else:
+            return temp_url
