@@ -97,7 +97,6 @@ EXAMPLE = {
     'name': 'new-server-test',
     'networks': 'auto',
     'os-extended-volumes:volumes_attached': [],
-    'personality': '28',
     'progress': 0,
     'security_groups': [
         {
@@ -225,7 +224,6 @@ class TestServer(base.TestCase):
                          sot.terminated_at)
         self.assertEqual(EXAMPLE['security_groups'], sot.security_groups)
         self.assertEqual(EXAMPLE['adminPass'], sot.admin_password)
-        self.assertEqual(EXAMPLE['personality'], sot.personality)
         self.assertEqual(EXAMPLE['block_device_mapping_v2'],
                          sot.block_device_mapping)
         self.assertEqual(EXAMPLE['OS-EXT-SRV-ATTR:host'],
@@ -259,7 +257,7 @@ class TestServer(base.TestCase):
         hints = {"hint": 3}
 
         sot = server.Server(id=1, availability_zone=zone, user_data=data,
-                            scheduler_hints=hints)
+                            scheduler_hints=hints, min_count=2, max_count=3)
         request = sot._prepare_request()
 
         self.assertNotIn("OS-EXT-AZ:availability_zone",
@@ -276,6 +274,9 @@ class TestServer(base.TestCase):
                          request.body[sot.resource_key])
         self.assertEqual(request.body["OS-SCH-HNT:scheduler_hints"], hints)
 
+        self.assertEqual(2, request.body[sot.resource_key]['min_count'])
+        self.assertEqual(3, request.body[sot.resource_key]['max_count'])
+
     def test_change_password(self):
         sot = server.Server(**EXAMPLE)
 
@@ -318,8 +319,7 @@ class TestServer(base.TestCase):
                              image='http://image/1', access_ipv4="12.34.56.78",
                              access_ipv6="fe80::100",
                              metadata={"meta var": "meta val"},
-                             personality=[{"path": "/etc/motd",
-                                           "contents": "foo"}])
+                             user_data="ZWNobyAiaGVsbG8gd29ybGQi")
 
         self.assertIsInstance(result, server.Server)
 
@@ -332,7 +332,7 @@ class TestServer(base.TestCase):
                 "accessIPv4": "12.34.56.78",
                 "accessIPv6": "fe80::100",
                 "metadata": {"meta var": "meta val"},
-                "personality": [{"path": "/etc/motd", "contents": "foo"}],
+                "user_data": "ZWNobyAiaGVsbG8gd29ybGQi",
                 "preserve_ephemeral": False
             }
         }
@@ -772,6 +772,20 @@ class TestServer(base.TestCase):
         self.sess.post.assert_called_with(
             url, json=body, headers=headers, microversion=None)
 
+    def test_unshelve_availability_zone(self):
+        sot = server.Server(**EXAMPLE)
+
+        res = sot.unshelve(self.sess, sot.availability_zone)
+
+        self.assertIsNone(res)
+        url = 'servers/IDENTIFIER/action'
+        body = {"unshelve": {
+            "availability_zone": sot.availability_zone
+        }}
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url, json=body, headers=headers, microversion=None)
+
     def test_migrate(self):
         sot = server.Server(**EXAMPLE)
 
