@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
-
 from openstack.network.v2 import network
+from openstack.tests.unit import base
+
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -45,17 +45,16 @@ EXAMPLE = {
 }
 
 
-class TestNetwork(testtools.TestCase):
+class TestNetwork(base.TestCase):
 
     def test_basic(self):
         sot = network.Network()
         self.assertEqual('network', sot.resource_key)
         self.assertEqual('networks', sot.resources_key)
         self.assertEqual('/networks', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
@@ -100,7 +99,7 @@ class TestNetwork(testtools.TestCase):
              'marker': 'marker',
              'description': 'description',
              'name': 'name',
-             'project_id': 'project_id',
+             'project_id': 'tenant_id',
              'status': 'status',
              'ipv4_address_scope_id': 'ipv4_address_scope',
              'ipv6_address_scope_id': 'ipv6_address_scope',
@@ -110,12 +109,16 @@ class TestNetwork(testtools.TestCase):
              'is_shared': 'shared',
              'provider_network_type': 'provider:network_type',
              'provider_physical_network': 'provider:physical_network',
-             'provider_segmentation_id': 'provider:segmentation_id'
+             'provider_segmentation_id': 'provider:segmentation_id',
+             'tags': 'tags',
+             'any_tags': 'tags-any',
+             'not_tags': 'not-tags',
+             'not_any_tags': 'not-tags-any',
              },
             sot._query_mapping._mapping)
 
 
-class TestDHCPAgentHostingNetwork(testtools.TestCase):
+class TestDHCPAgentHostingNetwork(base.TestCase):
 
     def test_basic(self):
         net = network.DHCPAgentHostingNetwork()
@@ -123,9 +126,8 @@ class TestDHCPAgentHostingNetwork(testtools.TestCase):
         self.assertEqual('networks', net.resources_key)
         self.assertEqual('/agents/%(agent_id)s/dhcp-networks', net.base_path)
         self.assertEqual('dhcp-network', net.resource_name)
-        self.assertEqual('network', net.service.service_type)
         self.assertFalse(net.allow_create)
-        self.assertTrue(net.allow_get)
-        self.assertFalse(net.allow_update)
+        self.assertTrue(net.allow_fetch)
+        self.assertFalse(net.allow_commit)
         self.assertFalse(net.allow_delete)
         self.assertTrue(net.allow_list)
